@@ -7,10 +7,12 @@ Created on 2015-7-9
 
 from PyFin.DateUtilities.Calendar import Calendar
 from PyFin.DateUtilities.Date import Date
+from PyFin.DateUtilities.Date import check_date
 from PyFin.DateUtilities.Period import Period
 from PyFin.DateUtilities.Schedule import Schedule
 
 __all__ = ['Calendar',
            'Date',
            'Period',
-           'Schedule']
+           'Schedule',
+           'check_date']
