@@ -16,14 +16,16 @@ from PyFin.Math.Accumulators.IAccumulators import Acos
 from PyFin.Math.Accumulators.IAccumulators import Acosh
 from PyFin.Math.Accumulators.IAccumulators import Asin
 from PyFin.Math.Accumulators.IAccumulators import Asinh
+from PyFin.Math.Accumulators.IAccumulators import Latest
+from PyFin.Math.Accumulators.IAccumulators import IIF
+from PyFin.Math.Accumulators.IAccumulators import Sign
+from PyFin.Math.Accumulators.IAccumulators import Negative
 
-from PyFin.Math.Accumulators.StatelessAccumulators import Latest
-from PyFin.Math.Accumulators.StatelessAccumulators import Sign
 from PyFin.Math.Accumulators.StatelessAccumulators import Diff
 from PyFin.Math.Accumulators.StatelessAccumulators import SimpleReturn
 from PyFin.Math.Accumulators.StatelessAccumulators import LogReturn
-from PyFin.Math.Accumulators.StatelessAccumulators import Positive
-from PyFin.Math.Accumulators.StatelessAccumulators import Negative
+from PyFin.Math.Accumulators.StatelessAccumulators import PositivePart
+from PyFin.Math.Accumulators.StatelessAccumulators import NegativePart
 from PyFin.Math.Accumulators.StatelessAccumulators import Max
 from PyFin.Math.Accumulators.StatelessAccumulators import Minimum
 from PyFin.Math.Accumulators.StatelessAccumulators import Sum
@@ -51,12 +53,15 @@ from PyFin.Math.Accumulators.StatefulAccumulators import MovingSum
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingCountedPositive
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingCountedNegative
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingVariance
+from PyFin.Math.Accumulators.StatefulAccumulators import MovingStandardDeviation
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingNegativeVariance
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingCorrelation
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingCorrelationMatrix
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingMax
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingMinimum
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingQuantile
+from PyFin.Math.Accumulators.StatefulAccumulators import MovingAllTrue
+from PyFin.Math.Accumulators.StatefulAccumulators import MovingAnyTrue
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingHistoricalWindow
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingProduct
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingCenterMoment
@@ -72,19 +77,19 @@ from PyFin.Math.Accumulators.StatefulAccumulators import MovingLevel
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingAroon
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingBias
 from PyFin.Math.Accumulators.StatefulAccumulators import MovingAutoCorrelation
-
-from PyFin.Math.Accumulators.Performancers import MovingLogReturn
-from PyFin.Math.Accumulators.Performancers import MovingAlphaBeta
-from PyFin.Math.Accumulators.Performancers import MovingDrawDown
-from PyFin.Math.Accumulators.Performancers import MovingAverageDrawdown
-from PyFin.Math.Accumulators.Performancers import MovingMaxDrawdown
-from PyFin.Math.Accumulators.Performancers import MovingSharp
-from PyFin.Math.Accumulators.Performancers import MovingSortino
+from PyFin.Math.Accumulators.StatefulAccumulators import MovingLogReturn
+from PyFin.Math.Accumulators.StatefulAccumulators import MovingAlphaBeta
+from PyFin.Math.Accumulators.StatefulAccumulators import MovingDrawDown
+from PyFin.Math.Accumulators.StatefulAccumulators import MovingAverageDrawdown
+from PyFin.Math.Accumulators.StatefulAccumulators import MovingMaxDrawdown
+from PyFin.Math.Accumulators.StatefulAccumulators import MovingSharp
+from PyFin.Math.Accumulators.StatefulAccumulators import MovingSortino
 
 __all__ = ["Exp",
            "Log",
            "Sqrt",
            "Sign",
+           "Negative",
            "Abs",
            "Pow",
            "Acos",
@@ -96,8 +101,8 @@ __all__ = ["Exp",
            "Diff",
            "SimpleReturn",
            "LogReturn",
-           "Positive",
-           "Negative",
+           "PositivePart",
+           "NegativePart",
            "Max",
            "Minimum",
            "Sum",
@@ -108,6 +113,7 @@ __all__ = ["Exp",
            "Variance",
            "Correlation",
            "Shift",
+           "IIF",
            "MovingAverage",
            "MovingPositiveAverage",
            "MovingNegativeAverage",
@@ -124,7 +130,10 @@ __all__ = ["Exp",
            "MovingMax",
            "MovingMinimum",
            "MovingQuantile",
+           "MovingAllTrue",
+           "MovingAnyTrue",
            "MovingVariance",
+           "MovingStandardDeviation",
            "MovingLogReturn",
            "MovingAlphaBeta",
            "MovingDrawDown",
