@@ -5,12 +5,10 @@ Created on 2015-7-23
 @author: cheng.li
 """
 
-from PyFin.Math.ErrorFunction import errorFunction
 from PyFin.Math import Accumulators
 from PyFin.Math import Distributions
 from PyFin.Math.MathConstants import MathConstants
 
-__all__ = ['errorFunction',
-           'Accumulators',
+__all__ = ['Accumulators',
            'Distributions',
            'MathConstants']
