@@ -11,8 +11,11 @@ from PyFin.Analysis.TechnicalAnalysis import SecurityMovingAverage
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingMax
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingMinimum
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingQuantile
+from PyFin.Analysis.TechnicalAnalysis import SecurityMovingAllTrue
+from PyFin.Analysis.TechnicalAnalysis import SecurityMovingAnyTrue
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingSum
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingVariance
+from PyFin.Analysis.TechnicalAnalysis import SecurityMovingStandardDeviation
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingCountedPositive
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingPositiveAverage
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingRSI
@@ -34,12 +37,13 @@ from PyFin.Analysis.TechnicalAnalysis import SecurityAsinValueHolder
 from PyFin.Analysis.TechnicalAnalysis import SecurityAsinhValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityShiftedValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityLatestValueHolder
-from PyFin.Analysis.SecurityValueHolders import SecurityWhereValueHolder
+from PyFin.Analysis.SecurityValueHolders import SecurityIIFValueHolder
 
 
 from PyFin.Analysis.CrossSectionValueHolders import CSRankedSecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSAverageSecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSAverageAdjustedSecurityValueHolder
+from PyFin.Analysis.CrossSectionValueHolders import CSZScoreSecurityValueHolder
 from PyFin.Analysis.CrossSectionValueHolders import CSQuantileSecurityValueHolder
 
 
@@ -56,6 +60,10 @@ def CSMeanAdjusted(dependency):
 
 
 def CSQuantile(dependency):
+    return CSZScoreSecurityValueHolder(dependency)
+
+
+def CSZScore(dependency):
     return CSQuantileSecurityValueHolder(dependency)
 
 
@@ -91,6 +99,14 @@ def QUANTILE(window, dependency='x'):
     return SecurityMovingQuantile(window, dependency)
 
 
+def ALLTRUE(window, dependency='x'):
+    return SecurityMovingAllTrue(window, dependency)
+
+
+def ANYTRUE(window, dependency='x'):
+    return SecurityMovingAnyTrue(window, dependency)
+
+
 def SUM(window, dependency='x'):
     return SecurityMovingSum(window, dependency)
 
@@ -99,6 +115,10 @@ def VARIANCE(window, dependency='x'):
     return SecurityMovingVariance(window, dependency)
 
 
+def STD(window, dependency='x'):
+    return SecurityMovingStandardDeviation(window, dependency)
+
+
 def NPOSITIVE(window, dependency='x'):
     return SecurityMovingCountedPositive(window, dependency)
 
@@ -168,7 +188,7 @@ def SHIFT(dependency, n):
 
 
 def IIF(flag, left, right):
-    return SecurityWhereValueHolder(flag, left, right)
+    return SecurityIIFValueHolder(flag, left, right)
 
 
 HIGH = functools.partial(LAST, 'high')
