@@ -11,9 +11,13 @@ import numpy as np
 import copy
 from collections import deque
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingAverage
+from PyFin.Analysis.TechnicalAnalysis import SecurityMovingVariance
+from PyFin.Analysis.TechnicalAnalysis import SecurityMovingStandardDeviation
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingMax
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingMinimum
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingQuantile
+from PyFin.Analysis.TechnicalAnalysis import SecurityMovingAllTrue
+from PyFin.Analysis.TechnicalAnalysis import SecurityMovingAnyTrue
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingSum
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingCountedPositive
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingPositiveAverage
@@ -45,13 +49,13 @@ class TestStatefulTechnicalAnalysis(unittest.TestCase):
             data = {'aapl': {'close': self.aapl['close'][i], 'open': self.aapl['open'][i]}}
             data['ibm'] = {'close': self.ibm['close'][i], 'open': self.ibm['open'][i]}
             ma1.push(data)
-            if i < 10:
+            if i < window:
                 start = 0
             else:
                 start = i + 1 - window
 
             value = ma1.value
-            for name in value.index:
+            for name in value.index():
                 expected = np.mean(self.dataSet[name]['close'][start:(i + 1)])
                 calculated = value[name]
                 self.assertAlmostEqual(expected, calculated, 12, 'at index {0}\n'
@@ -61,6 +65,64 @@ class TestStatefulTechnicalAnalysis(unittest.TestCase):
         with self.assertRaises(ValueError):
             _ = SecurityMovingAverage(window, ['close', 'open'])
 
+    def testSecurityMovingVariance(self):
+        window = 10
+        var = SecurityMovingVariance(window, ['close'])
+
+        for i in range(len(self.aapl['close'])):
+            data = {'aapl': {'close': self.aapl['close'][i], 'open': self.aapl['open'][i]}}
+            data['ibm'] = {'close': self.ibm['close'][i], 'open': self.ibm['open'][i]}
+
+            var.push(data)
+
+            if i <= 1:
+                continue
+
+            if i < window:
+                start = 0
+            else:
+                start = i + 1 - window
+
+            value = var.value
+            for name in value.index():
+                expected = np.var(self.dataSet[name]['close'][start:(i + 1)]) * (i + 1. - start) / (i - start)
+                calculated = value[name]
+                self.assertAlmostEqual(expected, calculated, 12, 'at index {0}\n'
+                                                                 'expected:   {1:.12f}\n'
+                                                                 'calculated: {2:.12f}'.format(i, expected, calculated))
+        with self.assertRaises(ValueError):
+            _ = SecurityMovingVariance(window, ['close', 'open'])
+
+    def testSecurityMovingStandardDeviation(self):
+        window = 10
+        std = SecurityMovingStandardDeviation(window, ['close'])
+
+        for i in range(len(self.aapl['close'])):
+            data = {'aapl': {'close': self.aapl['close'][i], 'open': self.aapl['open'][i]}}
+            data['ibm'] = {'close': self.ibm['close'][i], 'open': self.ibm['open'][i]}
+
+            std.push(data)
+
+            if i <= 1:
+                continue
+
+            if i < window:
+                start = 0
+            else:
+                start = i + 1 - window
+
+            value = std.value
+            for name in value.index():
+                expected = math.sqrt(
+                    np.var(self.dataSet[name]['close'][start:(i + 1)]) * (i + 1. - start) / (i - start))
+                calculated = value[name]
+                self.assertAlmostEqual(expected, calculated, 12, 'at index {0}\n'
+                                                                 'expected:   {1:.12f}\n'
+                                                                 'calculated: {2:.12f}'.format(i, expected,
+                                                                                               calculated))
+        with self.assertRaises(ValueError):
+            _ = SecurityMovingStandardDeviation(window, ['close', 'open'])
+
     def testSecurityMovingMax(self):
         window = 10
         ma1 = SecurityMovingMax(window, ['close'])
@@ -69,13 +131,13 @@ class TestStatefulTechnicalAnalysis(unittest.TestCase):
             data = {'aapl': {'close': self.aapl['close'][i], 'open': self.aapl['open'][i]}}
             data['ibm'] = {'close': self.ibm['close'][i], 'open': self.ibm['open'][i]}
             ma1.push(data)
-            if i < 10:
+            if i < window:
                 start = 0
             else:
                 start = i + 1 - window
 
             value = ma1.value
-            for name in value.index:
+            for name in value.index():
                 expected = np.max(self.dataSet[name]['close'][start:(i + 1)])
                 calculated = value[name]
                 self.assertAlmostEqual(expected, calculated, 12, 'at index {0}\n'
@@ -93,13 +155,13 @@ class TestStatefulTechnicalAnalysis(unittest.TestCase):
             data = {'aapl': {'close': self.aapl['close'][i], 'open': self.aapl['open'][i]}}
             data['ibm'] = {'close': self.ibm['close'][i], 'open': self.ibm['open'][i]}
             ma1.push(data)
-            if i < 10:
+            if i < window:
                 start = 0
             else:
                 start = i + 1 - window
 
             value = ma1.value
-            for name in value.index:
+            for name in value.index():
                 expected = np.min(self.dataSet[name]['close'][start:(i + 1)])
                 calculated = value[name]
                 self.assertAlmostEqual(expected, calculated, 12, 'at index {0}\n'
@@ -117,7 +179,7 @@ class TestStatefulTechnicalAnalysis(unittest.TestCase):
             data = {'aapl': {'close': self.aapl['close'][i], 'open': self.aapl['open'][i]}}
             data['ibm'] = {'close': self.ibm['close'][i], 'open': self.ibm['open'][i]}
             mq.push(data)
-            if i < 10:
+            if i < window:
                 start = 0
             else:
                 start = i + 1 - window
@@ -126,7 +188,7 @@ class TestStatefulTechnicalAnalysis(unittest.TestCase):
                 continue
 
             value = mq.value
-            for name in value.index:
+            for name in value.index():
                 con = self.dataSet[name]['close'][start:(i + 1)]
                 sorted_con = sorted(con)
                 expected = sorted_con.index(self.dataSet[name]['close'][i]) / (len(sorted_con) - 1.)
@@ -135,6 +197,64 @@ class TestStatefulTechnicalAnalysis(unittest.TestCase):
                                                                  'expected:   {1:.12f}\n'
                                                                  'calculated: {2:.12f}'.format(i, expected, calculated))
 
+    def testSecurityMovingAllTru(self):
+        window = 3
+
+        self.aapl['close'] = self.aapl['close'] > 0.
+        self.ibm['close'] = self.ibm['close'] > 0.
+
+        mq = SecurityMovingAllTrue(window, ['close'])
+
+        for i in range(len(self.aapl['close'])):
+            data = {'aapl': {'close': self.aapl['close'][i], 'open': self.aapl['open'][i]}}
+            data['ibm'] = {'close': self.ibm['close'][i], 'open': self.ibm['open'][i]}
+            mq.push(data)
+            if i < window:
+                start = 0
+            else:
+                start = i + 1 - window
+
+            if i < 1:
+                continue
+
+            value = mq.value
+            for name in value.index():
+                con = self.dataSet[name]['close'][start:(i + 1)]
+                expected = np.all(con)
+                calculated = value[name]
+                self.assertEqual(expected, calculated, 'at index {0}\n'
+                                                       'expected:   {1}\n'
+                                                       'calculated: {2}'.format(i, expected, calculated))
+
+    def testSecurityMovingAnyTru(self):
+        window = 3
+
+        self.aapl['close'] = self.aapl['close'] > 0.
+        self.ibm['close'] = self.ibm['close'] > 0.
+
+        mq = SecurityMovingAnyTrue(window, ['close'])
+
+        for i in range(len(self.aapl['close'])):
+            data = {'aapl': {'close': self.aapl['close'][i], 'open': self.aapl['open'][i]}}
+            data['ibm'] = {'close': self.ibm['close'][i], 'open': self.ibm['open'][i]}
+            mq.push(data)
+            if i < window:
+                start = 0
+            else:
+                start = i + 1 - window
+
+            if i < 1:
+                continue
+
+            value = mq.value
+            for name in value.index():
+                con = self.dataSet[name]['close'][start:(i + 1)]
+                expected = np.any(con)
+                calculated = value[name]
+                self.assertEqual(expected, calculated, 'at index {0}\n'
+                                                       'expected:   {1}\n'
+                                                       'calculated: {2}'.format(i, expected, calculated))
+
     def testSecurityMovingSum(self):
         window = 10
         ma1 = SecurityMovingSum(window, ['close'])
@@ -143,13 +263,13 @@ class TestStatefulTechnicalAnalysis(unittest.TestCase):
             data = {'aapl': {'close': self.aapl['close'][i], 'open': self.aapl['open'][i]}}
             data['ibm'] = {'close': self.ibm['close'][i], 'open': self.ibm['open'][i]}
             ma1.push(data)
-            if i < 10:
+            if i < window:
                 start = 0
             else:
                 start = i + 1 - window
 
             value = ma1.value
-            for name in value.index:
+            for name in value.index():
                 expected = np.sum(self.dataSet[name]['close'][start:(i + 1)])
                 calculated = value[name]
                 self.assertAlmostEqual(expected, calculated, 12, 'at index {0}\n'
@@ -164,13 +284,13 @@ class TestStatefulTechnicalAnalysis(unittest.TestCase):
             data = {'aapl': {'close': self.aapl['close'][i], 'open': self.aapl['open'][i]}}
             data['ibm'] = {'close': self.ibm['close'][i], 'open': self.ibm['open'][i]}
             ma1.push(data)
-            if i < 10:
+            if i < window:
                 start = 0
             else:
                 start = i + 1 - window
 
             value = ma1.value
-            for name in value.index:
+            for name in value.index():
                 expected = np.sum(self.dataSet[name]['close'][start:(i + 1)] > 0.0)
                 calculated = value[name]
                 self.assertAlmostEqual(expected, calculated, 12, 'at index {0}\n'
@@ -188,13 +308,13 @@ class TestStatefulTechnicalAnalysis(unittest.TestCase):
             data = {'aapl': {'close': self.aapl['close'][i], 'open': self.aapl['open'][i]}}
             data['ibm'] = {'close': self.ibm['close'][i], 'open': self.ibm['open'][i]}
             ma1.push(data)
-            if i < 10:
+            if i < window:
                 start = 0
             else:
                 start = i + 1 - window
 
             value = ma1.value
-            for name in value.index:
+            for name in value.index():
                 sampled = list(filter(lambda x: x > 0, self.dataSet[name]['close'][start:(i + 1)]))
                 if len(sampled) > 0:
                     expected = np.mean(sampled)
@@ -223,7 +343,7 @@ class TestStatefulTechnicalAnalysis(unittest.TestCase):
 
             value = rsi.value
             if i > 0:
-                for name in value.index:
+                for name in value.index():
                     expected = pos_avg.value[name] / (pos_avg.value[name] - neg_avg.value[name]) * 100
                     calculated = value[name]
                     self.assertAlmostEqual(expected, calculated, 12, 'at index {0}\n'
@@ -245,13 +365,13 @@ class TestStatefulTechnicalAnalysis(unittest.TestCase):
             data = {'aapl': {'close': self.newDataSet['aapl']['close'][i], 'open': self.newDataSet['aapl']['open'][i]}}
             data['ibm'] = {'close': self.newDataSet['ibm']['close'][i], 'open': self.newDataSet['ibm']['open'][i]}
             ma1.push(data)
-            if i < 10:
+            if i < window:
                 start = 0
             else:
                 start = i - window
 
             value = ma1.value
-            for name in value.index:
+            for name in value.index():
                 sampled = self.newDataSet[name]['close'][start:(i + 1)]
                 if i >= 10:
                     expected = math.log(sampled[-1] / sampled[0])
@@ -283,7 +403,7 @@ class TestStatefulTechnicalAnalysis(unittest.TestCase):
                 container = mh.value
                 for k in range(min(i + 1, window)):
                     calculated = mh[k]
-                    for name in calculated.index:
+                    for name in calculated.index():
                         self.assertAlmostEqual(calculated[name], benchmark[name][-1 - k],
                                                "at index {0} positon {1} and symbol {2}\n"
                                                "expected:   {3}\n"
@@ -292,7 +412,7 @@ class TestStatefulTechnicalAnalysis(unittest.TestCase):
                                                                         calculated[name]))
                 # check by value method
                 for k in range(min(i + 1, window)):
-                    for name in calculated.index:
+                    for name in calculated.index():
                         self.assertAlmostEqual(container[name][k], benchmark[name][-1 - k],
                                                "at index {0} positon {1} and symbol {2}\n"
                                                "expected:   {3}\n"
