@@ -9,11 +9,11 @@ import unittest
 import numpy as np
 import pandas as pd
 from PyFin.Enums import Factors
-from PyFin.Analysis.SecurityValueHolders import SecuritiesValues
+from PyFin.Analysis.SecurityValues import SecurityValues
 from PyFin.Analysis.SecurityValueHolders import dependencyCalculator
 from PyFin.Analysis.SecurityValueHolders import FilteredSecurityValueHolder
 from PyFin.Analysis.SecurityValueHolders import SecurityLatestValueHolder
-from PyFin.Analysis.SecurityValueHolders import SecurityWhereValueHolder
+from PyFin.Analysis.SecurityValueHolders import SecurityIIFValueHolder
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingAverage
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingMax
 from PyFin.Analysis.TechnicalAnalysis import SecurityMovingMinimum
@@ -30,7 +30,7 @@ class TestSecurityValueHolders(unittest.TestCase):
                       'ibm': {'close': sample2[:, 0], 'open': sample2[:, 1]}}
 
         def check_values(expected, calculated):
-            for name in calculated:
+            for name in calculated.index():
                 self.assertEqual(calculated[name], expected[name], "for the name {0}\n"
                                                                    "expected:   {1}\n"
                                                                    "calculated: {2}".format(name,
@@ -41,7 +41,7 @@ class TestSecurityValueHolders(unittest.TestCase):
     def testSecurityWhereValueHolder(self):
         benchmark = SecurityLatestValueHolder(dependency='close')
 
-        testValueHolder = SecurityWhereValueHolder(benchmark > 0, benchmark, -benchmark)
+        testValueHolder = SecurityIIFValueHolder(benchmark > 0, benchmark, -benchmark)
         for i in range(len(self.datas['aapl']['close'])):
             data = {'aapl': {Factors.CLOSE: self.datas['aapl'][Factors.CLOSE][i],
                              Factors.OPEN: self.datas['aapl'][Factors.OPEN][i]},
@@ -52,9 +52,9 @@ class TestSecurityValueHolders(unittest.TestCase):
 
             calculated = testValueHolder.value
 
-            self.assertTrue(np.all(calculated > 0.))
+            self.assertTrue(np.all((calculated > 0.).values))
 
-            for name in calculated.index:
+            for name in calculated.index():
                 rawValue = data[name][Factors.CLOSE]
                 if rawValue > 0.:
                     self.assertAlmostEqual(rawValue, calculated[name])
@@ -75,7 +75,7 @@ class TestSecurityValueHolders(unittest.TestCase):
             testValueHolder.push(data)
             calculated = testValueHolder.value
 
-            for name in calculated.index:
+            for name in calculated.index():
                 close_value = data[name][Factors.CLOSE]
                 open_value = data[name][Factors.OPEN]
 
@@ -98,7 +98,7 @@ class TestSecurityValueHolders(unittest.TestCase):
             testValueHolder.push(data)
             calculated = testValueHolder.value
 
-            for name in calculated.index:
+            for name in calculated.index():
                 close_value = data[name][Factors.CLOSE]
                 open_value = data[name][Factors.OPEN]
 
@@ -110,7 +110,7 @@ class TestSecurityValueHolders(unittest.TestCase):
     def testSecurityWhereValueHolderWithSymbolName(self):
         benchmark = SecurityLatestValueHolder(dependency='close')
 
-        testValueHolder = SecurityWhereValueHolder(benchmark > 0, 'open', -benchmark)
+        testValueHolder = SecurityIIFValueHolder(benchmark > 0, 'open', -benchmark)
         for i in range(len(self.datas['aapl']['close'])):
             data = {'aapl': {Factors.CLOSE: self.datas['aapl'][Factors.CLOSE][i],
                              Factors.OPEN: self.datas['aapl'][Factors.OPEN][i]},
@@ -121,14 +121,14 @@ class TestSecurityValueHolders(unittest.TestCase):
 
             calculated = testValueHolder.value
 
-            for name in calculated.index:
+            for name in calculated.index():
                 rawValue = data[name][Factors.CLOSE]
                 if rawValue > 0.:
                     self.assertAlmostEqual(data[name][Factors.OPEN], calculated[name])
                 else:
                     self.assertAlmostEqual(-rawValue, calculated[name])
 
-        testValueHolder = SecurityWhereValueHolder(benchmark > 0, 'open', 'close')
+        testValueHolder = SecurityIIFValueHolder(benchmark > 0, 'open', 'close')
         for i in range(len(self.datas['aapl']['close'])):
             data = {'aapl': {Factors.CLOSE: self.datas['aapl'][Factors.CLOSE][i],
                              Factors.OPEN: self.datas['aapl'][Factors.OPEN][i]},
@@ -139,7 +139,7 @@ class TestSecurityValueHolders(unittest.TestCase):
 
             calculated = testValueHolder.value
 
-            for name in calculated.index:
+            for name in calculated.index():
                 rawValue = data[name][Factors.CLOSE]
                 if rawValue > 0.:
                     self.assertAlmostEqual(data[name][Factors.OPEN], calculated[name])
@@ -149,7 +149,7 @@ class TestSecurityValueHolders(unittest.TestCase):
     def testSecurityWhereValueHolderWithMissingSymbol(self):
         benchmark = SecurityLatestValueHolder(dependency='open')
         benchmark2 = SecurityLatestValueHolder(dependency='close')
-        testValueHolder = SecurityWhereValueHolder(benchmark < 0, 'open', -benchmark2)
+        testValueHolder = SecurityIIFValueHolder(benchmark < 0, 'open', -benchmark2)
 
         data = {'aapl': {'close': 2.0, 'open': 1.5},
                 'ibm': {'open': 1.7}}
@@ -163,6 +163,28 @@ class TestSecurityValueHolders(unittest.TestCase):
         self.assertAlmostEqual(calculated['aapl'], -data['aapl']['close'])
         self.assertTrue(np.isnan(calculated['ibm']))
 
+    def testSecurityWhereValueHolderWithScalarValue(self):
+        benchmark = SecurityLatestValueHolder(dependency='open')
+        testValueHolder = SecurityIIFValueHolder(benchmark > 0, 1., -1.)
+        for i in range(len(self.datas['aapl']['close'])):
+            data = {'aapl': {Factors.CLOSE: self.datas['aapl'][Factors.CLOSE][i],
+                             Factors.OPEN: self.datas['aapl'][Factors.OPEN][i]},
+                    'ibm': {Factors.CLOSE: self.datas['ibm'][Factors.CLOSE][i],
+                            Factors.OPEN: self.datas['ibm'][Factors.OPEN][i]}}
+            benchmark.push(data)
+            testValueHolder.push(data)
+
+            calculated = testValueHolder.value
+
+            for name in calculated.index():
+                rawValue = data[name][Factors.OPEN]
+                if rawValue > 0.:
+                    self.assertAlmostEqual(1., calculated[name])
+                    self.assertAlmostEqual(1., testValueHolder.value_by_name(name))
+                else:
+                    self.assertAlmostEqual(-1., calculated[name])
+                    self.assertAlmostEqual(-1., testValueHolder.value_by_name(name))
+
     def testFilteredSecurityValueHolder(self):
         benchmark = SecurityLatestValueHolder(dependency='close') > 0
         filtered = FilteredSecurityValueHolder(benchmark, benchmark)
@@ -223,11 +245,13 @@ class TestSecurityValueHolders(unittest.TestCase):
             rawHolder.push(data)
             filteredHolder.push(data)
 
-            self.assertTrue(np.all(filteredHolder.value >= 0.))
+            filteredValues = filteredHolder.value >= 0.
+
+            self.assertTrue(np.all(filteredValues.values))
 
             rawValues = rawHolder.value
             filteredValues = filteredHolder.value
-            for name in rawValues.index:
+            for name in rawValues.index():
                 if rawValues[name] >= 0.:
                     self.assertTrue(name in filteredValues)
 
@@ -249,64 +273,64 @@ class TestSecurityValueHolders(unittest.TestCase):
 
     def testSecuritiesValuesComparison(self):
 
-        benchmarkValues = SecuritiesValues({'AAPL': 1.0, 'IBM': 2.0, 'GOOG': 3.0})
+        benchmarkValues = SecurityValues({'AAPL': 1.0, 'IBM': 2.0, 'GOOG': 3.0})
         calculated = benchmarkValues > 1.5
-        expected = SecuritiesValues({'AAPL': False, 'IBM': True, 'GOOG': True})
+        expected = SecurityValues({'AAPL': False, 'IBM': True, 'GOOG': True})
         self.checker(expected, calculated)
 
         calculated = benchmarkValues < 1.5
-        expected = SecuritiesValues({'AAPL': True, 'IBM': False, 'GOOG': False})
+        expected = SecurityValues({'AAPL': True, 'IBM': False, 'GOOG': False})
         self.checker(expected, calculated)
 
         calculated = benchmarkValues >= 1.0
-        expected = SecuritiesValues({'AAPL': True, 'IBM': True, 'GOOG': True})
+        expected = SecurityValues({'AAPL': True, 'IBM': True, 'GOOG': True})
         self.checker(expected, calculated)
 
         calculated = benchmarkValues <= 2.0
-        expected = SecuritiesValues({'AAPL': True, 'IBM': True, 'GOOG': False})
+        expected = SecurityValues({'AAPL': True, 'IBM': True, 'GOOG': False})
         self.checker(expected, calculated)
 
-        benchmarkValues = SecuritiesValues({'AAPL': False, 'IBM': True, 'GOOG': False})
+        benchmarkValues = SecurityValues({'AAPL': False, 'IBM': True, 'GOOG': False})
         calculated = benchmarkValues & True
-        expected = SecuritiesValues({'AAPL': False, 'IBM': True, 'GOOG': False})
+        expected = SecurityValues({'AAPL': False, 'IBM': True, 'GOOG': False})
         self.checker(expected, calculated)
 
         calculated = True & benchmarkValues
-        expected = SecuritiesValues({'AAPL': False, 'IBM': True, 'GOOG': False})
+        expected = SecurityValues({'AAPL': False, 'IBM': True, 'GOOG': False})
         self.checker(expected, calculated)
 
         calculated = benchmarkValues | True
-        expected = SecuritiesValues({'AAPL': True, 'IBM': True, 'GOOG': True})
+        expected = SecurityValues({'AAPL': True, 'IBM': True, 'GOOG': True})
         self.checker(expected, calculated)
 
         calculated = True | benchmarkValues
-        expected = SecuritiesValues({'AAPL': True, 'IBM': True, 'GOOG': True})
+        expected = SecurityValues({'AAPL': True, 'IBM': True, 'GOOG': True})
         self.checker(expected, calculated)
 
-        benchmarkValues = SecuritiesValues({'AAPL': 1.0, 'IBM': 2.0, 'GOOG': 3.0})
+        benchmarkValues = SecurityValues({'AAPL': 1.0, 'IBM': 2.0, 'GOOG': 3.0})
         calculated = benchmarkValues == 2.0
-        expected = SecuritiesValues({'AAPL': False, 'IBM': True, 'GOOG': False})
+        expected = SecurityValues({'AAPL': False, 'IBM': True, 'GOOG': False})
         self.checker(expected, calculated)
 
         calculated = benchmarkValues != 2.0
-        expected = SecuritiesValues({'AAPL': True, 'IBM': False, 'GOOG': True})
+        expected = SecurityValues({'AAPL': True, 'IBM': False, 'GOOG': True})
         self.checker(expected, calculated)
 
     def testSecuritiesValuesArithmetic(self):
         benchmarkValues = {'AAPL': 1.0, 'IBM': 2.0, 'GOOG': 3.0}
-        values = SecuritiesValues(benchmarkValues)
+        values = SecurityValues(benchmarkValues)
 
         self.assertEqual(len(benchmarkValues), len(values))
 
         for key in benchmarkValues:
             self.assertAlmostEqual(benchmarkValues[key], values[key], 12)
 
-        negValues = - values
+        negValues = -values
         for key in benchmarkValues:
             self.assertAlmostEqual(benchmarkValues[key], -negValues[key], 12)
 
         benchmarkValues2 = {'AAPL': 3.0, 'IBM': 2.0, 'GOOG': 1.0}
-        values2 = SecuritiesValues(benchmarkValues2)
+        values2 = SecurityValues(benchmarkValues2)
         addedValue = values + values2
         for key in benchmarkValues:
             self.assertAlmostEqual(benchmarkValues[key] + benchmarkValues2[key], addedValue[key], 12)
@@ -375,20 +399,16 @@ class TestSecurityValueHolders(unittest.TestCase):
         test2 = SecurityMovingMax(window2, pNames2)
         binaryValueHolder = testValueHolder + test2
 
-        self.assertEqual(set(binaryValueHolder.symbolList), set(symbolList))
-
         self.assertEqual(binaryValueHolder.valueSize, 1)
         self.assertEqual(binaryValueHolder.window, max(window, window2))
 
         # test compounded operated value holder
         test3 = SecurityMovingMax(window2, testValueHolder)
-        self.assertEqual(set(test3.symbolList), set(symbolList))
         self.assertEqual(test3.valueSize, 1)
         self.assertEqual(test3.window, window + window2)
 
         # test compounded twice
         test4 = SecurityMovingMax(window2, test3)
-        self.assertEqual(set(test4.symbolList), set(symbolList))
         self.assertEqual(test4.valueSize, 1)
         self.assertEqual(test4.window, window + 2 * window2)
 
@@ -436,7 +456,7 @@ class TestSecurityValueHolders(unittest.TestCase):
 
             expected = ma.value + mm.value
             calculated = combined.value
-            for name in expected.index:
+            for name in expected.index():
                 self.assertAlmostEqual(expected[name], calculated[name], 12)
 
     def testAddedSecurityValueHoldersWithScalar(self):
@@ -454,7 +474,7 @@ class TestSecurityValueHolders(unittest.TestCase):
 
             expected = 2.0 + mm.value
             calculated = combined.value
-            for name in expected.index:
+            for name in expected.index():
                 self.assertAlmostEqual(expected[name], calculated[name], 12)
 
     def testAddedSecurityValueHolderWithName(self):
@@ -473,7 +493,7 @@ class TestSecurityValueHolders(unittest.TestCase):
 
             base = mm.value
             calculated = combined.value
-            for name in calculated.index:
+            for name in calculated.index():
                 self.assertAlmostEqual(base[name] + data[name]['open'], calculated[name], 12)
 
     def testRAddedSecurityValueHoldersWithScalar(self):
@@ -491,7 +511,7 @@ class TestSecurityValueHolders(unittest.TestCase):
 
             expected = ma.value + 2.0
             calculated = combined.value
-            for name in expected.index:
+            for name in expected.index():
                 self.assertAlmostEqual(expected[name], calculated[name], 12)
 
     def testSubbedSecurityValueHolder(self):
@@ -514,7 +534,7 @@ class TestSecurityValueHolders(unittest.TestCase):
 
             expected = ma.value - mm.value
             calculated = combined.value
-            for name in expected.index:
+            for name in expected.index():
                 self.assertAlmostEqual(expected[name], calculated[name], 12)
 
     def testSubbedSecurityValueHoldersWithScalar(self):
@@ -532,7 +552,7 @@ class TestSecurityValueHolders(unittest.TestCase):
 
             expected = 2.0 - mm.value
             calculated = combined.value
-            for name in expected.index:
+            for name in expected.index():
                 self.assertAlmostEqual(expected[name], calculated[name], 12)
 
     def testRSubbedSecurityValueHoldersWithScalar(self):
@@ -550,7 +570,7 @@ class TestSecurityValueHolders(unittest.TestCase):
 
             expected = ma.value - 2.0
             calculated = combined.value
-            for name in expected.index:
+            for name in expected.index():
                 self.assertAlmostEqual(expected[name], calculated[name], 12)
 
     def testMultipliedSecurityValueHolders(self):
@@ -573,7 +593,7 @@ class TestSecurityValueHolders(unittest.TestCase):
 
             expected = ma.value * mm.value
             calculated = combined.value
-            for name in expected.index:
+            for name in expected.index():
                 self.assertAlmostEqual(expected[name], calculated[name], 12)
 
     def testMultipliedSecurityValueHoldersWithScalar(self):
@@ -591,7 +611,7 @@ class TestSecurityValueHolders(unittest.TestCase):
 
             expected = 2.0 * mm.value
             calculated = combined.value
-            for name in expected.index:
+            for name in expected.index():
                 self.assertAlmostEqual(expected[name], calculated[name], 12)
 
     def testRMultipliedSecurityValueHoldersWithScalar(self):
@@ -609,7 +629,7 @@ class TestSecurityValueHolders(unittest.TestCase):
 
             expected = ma.value * 2.0
             calculated = combined.value
-            for name in expected.index:
+            for name in expected.index():
                 self.assertAlmostEqual(expected[name], calculated[name], 12)
 
     def testDividedSecurityValueHolders(self):
@@ -632,7 +652,7 @@ class TestSecurityValueHolders(unittest.TestCase):
 
             expected = ma.value / mm.value
             calculated = combined.value
-            for name in expected.index:
+            for name in expected.index():
                 self.assertAlmostEqual(expected[name], calculated[name], 12)
 
     def testDividedSecurityValueHoldersWithScalar(self):
@@ -650,7 +670,7 @@ class TestSecurityValueHolders(unittest.TestCase):
 
             expected = 2.0 / mm.value
             calculated = combined.value
-            for name in expected.index:
+            for name in expected.index():
                 self.assertAlmostEqual(expected[name], calculated[name], 12)
 
     def testRDividedSecurityValueHoldersWithScalar(self):
@@ -668,14 +688,14 @@ class TestSecurityValueHolders(unittest.TestCase):
 
             expected = ma.value / 2.0
             calculated = combined.value
-            for name in expected.index:
+            for name in expected.index():
                 self.assertAlmostEqual(expected[name], calculated[name], 12)
 
     def testCombinedSecurityValueHolderWithoutData(self):
         ma = SecurityMovingAverage(10, 'close')
         calculated = ma.value
 
-        for name in calculated.index:
+        for name in calculated.index():
             self.assertTrue(np.isnan(calculated[name]))
 
     def testShiftedSecurityValueHolder(self):
@@ -687,7 +707,7 @@ class TestSecurityValueHolders(unittest.TestCase):
                  'goog': {'close': 3.0}}
         shifted1.push(data1)
         calculated = shifted1.value
-        for name in calculated.index:
+        for name in calculated.index():
             self.assertTrue(np.isnan(calculated[name]))
 
         data2 = {'aapl': {'close': 2.0},
@@ -695,11 +715,11 @@ class TestSecurityValueHolders(unittest.TestCase):
                  'goog': {'close': 4.0}}
 
         shifted1.push(data2)
-        expected = SecuritiesValues({'aapl': 1.0,
+        expected = SecurityValues({'aapl': 1.0,
                    'ibm': 2.0,
                    'goog': 3.0})
         calculated = shifted1.value
-        for name in expected.index:
+        for name in expected.index():
             self.assertAlmostEqual(expected[name], calculated[name])
 
         data3 = ({'aapl': {'close': 3.0},
@@ -707,11 +727,11 @@ class TestSecurityValueHolders(unittest.TestCase):
                  'goog': {'close': 5.0}})
 
         shifted1.push(data3)
-        expected = SecuritiesValues({'aapl': 1.5,
+        expected = SecurityValues({'aapl': 1.5,
                     'ibm': 2.5,
                     'goog': 3.5})
         calculated = shifted1.value
-        for name in expected.index:
+        for name in expected.index():
             self.assertAlmostEqual(expected[name], calculated[name])
 
     def testShiftedSecurityValueHolderWithLengthZero(self):
@@ -819,7 +839,8 @@ class TestSecurityValueHolders(unittest.TestCase):
         test_df = pd.DataFrame({'code': [1, 2, 3, 4, 1, 2, 3],
                                 'b': [4, 5, 6, 7, 6, 5, 4],
                                 'c': [9, 8, 7, 6, 5, 4, 3]},
-                               index=[1, 1, 1, 1, 2, 2, 2])
+                               index=[1, 1, 1, 1, 2, 2, 2],
+                               dtype=float)
 
         expression = SecurityMovingMax(20, 'b') + SecurityMovingMinimum(20, 'c')
         calculated = expression.transform(test_df, name='new_factor', category_field='code')
@@ -830,7 +851,8 @@ class TestSecurityValueHolders(unittest.TestCase):
     def testTransformWithoutCategory(self):
         test_df = pd.DataFrame({'b': [4, 5, 6, 7, 6, 5, 4],
                                 'c': [9, 8, 7, 6, 5, 4, 3]},
-                               index=[1, 2, 3, 4, 5, 6, 7])
+                               index=[1, 2, 3, 4, 5, 6, 7],
+                               dtype=float)
 
         expression = SecurityMovingMax(20, 'b') + SecurityMovingMinimum(20, 'c')
         calculated = expression.transform(test_df, name='new_factor')
@@ -841,7 +863,8 @@ class TestSecurityValueHolders(unittest.TestCase):
         test_df = pd.DataFrame({'code': [1, 2, 3, 4, 5, 6, 7],
                                 'b': [4, 5, 6, 7, 6, 5, 4],
                                 'c': [9, 8, 7, 6, 5, 4, 3]},
-                               index=[1, 1, 1, 1, 2, 2, 2])
+                               index=[1, 1, 1, 1, 2, 2, 2],
+                               dtype=float)
 
         expression = SecurityMovingAverage(2, 'b')
         calculated = expression.transform(test_df, name='new_factor', category_field='code')
@@ -854,7 +877,8 @@ class TestSecurityValueHolders(unittest.TestCase):
             data={'code': [1, 2, 1, 2, 1, 2],
                   'open': [2.0, 1.0, 1.5, 3.0, 2.4, 3.5],
                   'close': [1.7, 1.6, 0.9, 3.8, 1.6, 2.1]},
-            index=[1, 1, 2, 2, 3, 3]
+            index=[1, 1, 2, 2, 3, 3],
+            dtype=float
         )
 
         expression = SecurityMovingAverage(2, 'close')
